<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.x-cart.com/license-agreement.html
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2015 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @license   http://www.x-cart.com/license-agreement.html X-Cart 5 License Agreement
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\CDev\Egoods\View\Tabs;

/**
 * Tabs related to user profile section
 */
class Account extends \XLite\View\Tabs\Account implements \XLite\Base\IDecorator
{
    /**
     * Override constructor to add new tab
     *
     * @param array $params Handler params OPTIONAL
     *
     * @return void
     */
    public function __construct(array $params = array())
    {
        parent::__construct($params);

        if ($this->getOrdersWithFiles()) {
            $this->tabs['ordered_files'] = array(
                'title'    => 'Ordered files',
                'template' => 'modules/CDev/Egoods/files.tpl',
            );
        }
    }

    /**
     * Returns the list of targets where this widget is available
     *
     * @return void
     */
    public static function getAllowedTargets()
    {
        $list = parent::getAllowedTargets();        
        $list[] = 'ordered_files';
        
        return $list;
    }

    /**
     * Returns an array(tab) descriptions
     *
     * @return array
     */
    protected function getTabs()
    {
        if (!isset($this->processedTabs) && $this->getOrdersWithFiles()) {
            $this->tabs['ordered_files'] = array(
                'title'   => 'Ordered files',
                'template' => 'modules/CDev/Egoods/files.tpl',
            );
        }
        parent::getTabs();
        return $this->processedTabs;
    }

    /**
     * Get orders with files 
     * 
     * @return array
     */
    public function getOrdersWithFiles()
    {
        return \XLite\Core\Database::getRepo('\XLite\Model\Order')->findAllOrdersWithEgoods($this->getProfile());
    }
}
