<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.x-cart.com/license-agreement.html
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2015 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @license   http://www.x-cart.com/license-agreement.html X-Cart 5 License Agreement
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\CDev\Wholesale\Logic\Export\Step;

/**
 * Products
 */
abstract class Products extends \XLite\Logic\Export\Step\Products implements \XLite\Base\IDecorator
{
    /**
     * Define columns
     *
     * @return array
     */
    protected function defineColumns()
    {
        $columns = parent::defineColumns();

        $columns['wholesalePrices'] = array();

        return $columns;
    }

    /**
     * Get column value for 'wholesalePrices' column
     *
     * @param array   $dataset Dataset
     * @param string  $name    Column name
     * @param integer $i       Subcolumn index
     *
     * @return array
     */
    protected function getWholesalePricesColumnValue(array $dataset, $name, $i)
    {
        $cnd = new \XLite\Core\CommonCell();
        $cnd->{\XLite\Module\CDev\Wholesale\Model\Repo\WholesalePrice::P_PRODUCT} = $dataset['model'];

        return $this->convertWholesalePrices(
            \XLite\Core\Database::getRepo('XLite\Module\CDev\Wholesale\Model\WholesalePrice')->search($cnd)
        );
    }

    /**
     * Get Wholesale prices
     *
     * @param array $prices
     *
     * @return array
     */
    protected function convertWholesalePrices(array $prices)
    {
        $result = array();

        foreach ($prices as $price) {
            $str = $price->getQuantityRangeBegin();

            if (0 < $price->getQuantityRangeEnd()) {
                $str .= '-' . $price->getQuantityRangeEnd();
            }

            if ($price->getMembership()) {
                $str .= '(' . $this->formatMembershipModel($price->getMembership()) . ')';
            }

            $str .= '=' . $price->getPrice();

            $result[] = $str;
        }

        return $result;
    }
}
