<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.x-cart.com/license-agreement.html
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2015 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @license   http://www.x-cart.com/license-agreement.html X-Cart 5 License Agreement
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\XC\ColorSchemes\Core;

/**
 * Layout manager
 */
abstract class Layout extends \XLite\Module\CDev\SimpleCMS\Core\Layout implements \XLite\Base\IDecorator
{
    /**
     * Defines the LESS files to be part of the main LESS queue
     *
     * @param string $interface Interface to use: admin or customer values
     *
     * @return array
     */
    public function getLESSResources($interface)
    {
        $result = parent::getLESSResources($interface);
        $colorScheme = \XLite\Module\XC\ColorSchemes\Main::getColorSchemeLess();

        if (\XLite::CUSTOMER_INTERFACE === $interface && !\XLite\Module\XC\ColorSchemes\Main::isDefaultColorScheme()) {
            $result[] = $colorScheme;
        }

        return $result;
    }

    /**
     * Returns skin preview image URL
     *
     * @param \XLite\Model\Module $module Skin module
     * @param string              $color  Color
     * @param string              $type   Layout type
     *
     * @return string
     */
    public function getLayoutPreview($module, $color, $type)
    {
        $skinModule = ($module
            && '' === $color
            && 'XC' === $module->getAuthor()
            && 'ColorSchemes' === $module->getName()
        )
            ? null
            : $module;

        return parent::getLayoutPreview($skinModule, $color, $type);
    }
}
