<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.x-cart.com/license-agreement.html
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2015 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @license   http://www.x-cart.com/license-agreement.html X-Cart 5 License Agreement
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\XC\Reviews\View\ItemsList\Model;

/**
 * Reviews list for tab in product details page
 *
 */
class ProductReview extends \XLite\Module\XC\Reviews\View\ItemsList\Model\Review
{
    /**
     * Widget param names
     */
    const PARAM_PRODUCT_ID = 'product_id';

    /**
     * Define columns structure
     *
     * @return array
     */
    protected function defineColumns()
    {
        $allowedColumns = array(
            'reviewerName',
            'rating',
            'status',
            'additionDate',
        );

        $columns = parent::defineColumns();

        // Remove redundant columns
        foreach ($columns as $k => $v) {
            if (!in_array($k, $allowedColumns)) {
                unset($columns[$k]);
            }
        }

        $columns['useForMeta'] = array(
            static::COLUMN_NAME      => static::t('SEO'),
            static::COLUMN_HEAD_HELP => static::t('Select the review that should be included into the rich snippet shown for the page of this product when the page appears in search results by Google and other major search engines'),
            static::COLUMN_CLASS     => '\XLite\View\FormField\Inline\Input\Radio\Radio',
            static::COLUMN_EDIT_ONLY => true,
            static::COLUMN_PARAMS => array(
                'fieldName' => 'useForMeta',
            ),
            static::COLUMN_ORDERBY   => 600,
        );

        return $columns;
    }

    /**
     * Get create entity URL
     *
     * @return string
     */
    protected function getCreateURL()
    {
        return \XLite\Core\Converter::buildURL('review');
    }

    /**
     * Return params list to use for search
     *
     * @return \XLite\Core\CommonCell
     */
    protected function getSearchCondition()
    {
        $result = parent::getSearchCondition();

        $productId = $this->getProductId();

        $result->{\XLite\Module\XC\Reviews\Model\Repo\Review::SEARCH_PRODUCT}
            = \XLite\Core\Database::getRepo('XLite\Model\Product')->find($productId);

        return $result;
    }

    /**
     * Get AJAX-specific URL parameters
     *
     * @return array
     */
    protected function getAJAXSpecificParams()
    {
        $params = parent::getAJAXSpecificParams();
        $params[static::PARAM_PRODUCT_ID] = $this->getProductId();

        return $params;
    }

    /**
     * Check if the simple class is used for widget displaying
     *
     * @param array                $column Column
     * @param \XLite\Model\AEntity $entity Entity
     *
     * @return boolean
     */
    protected function isClassColumnVisible(array $column, \XLite\Model\AEntity $entity)
    {
        $result = parent::isClassColumnVisible($column, $entity);

        if ('useForMeta' ==  $column[static::COLUMN_CODE]) {
            $result = $result && $entity->isApproved();
        }

        return $result;
    }
}
