<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.x-cart.com/license-agreement.html
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2015 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @license   http://www.x-cart.com/license-agreement.html X-Cart 5 License Agreement
 * @link      http://www.x-cart.com/
 */

namespace XLite\View;

/**
 * Checkout failed page
 *
 */
abstract class ACheckoutFailed extends \XLite\View\AView
{
    /**
     * Get a list of CSS files required to display the widget properly
     *
     * @return array
     */
    public function getCSSFiles()
    {
        $list = parent::getJSFiles();
        $list[] = 'checkout/checkout.css';

        return $list;
    }

    /**
     * Get continue URL
     *
     * @return string
     */
    protected function getContinueURL()
    {
        if (\XLite\Core\Session::getInstance()->continueShoppingURL) {
            $url = $this->getURL(\XLite\Core\Session::getInstance()->continueShoppingURL);

        } elseif (isset($_SERVER['HTTP_REFERER'])) {
            $url = $_SERVER['HTTP_REFERER'];

        } else {
            $url = $this->buildURL();
        }

        return $url;
    }

    /**
     * Get Re-order URL
     *
     * @return string
     */
    protected function getReorderURL()
    {
        return $this->buildURL('cart', 'add_order', array('order_number' => $this->getOrder()->getOrderNumber()));
    }

    /**
     * Get failure reason
     *
     * @return string
     */
    protected function getFailureReason()
    {
        return $this->getOrder()
            ? $this->getOrder()->getFailureReason()
            : null;
    }

    /**
     * Return widget default template
     *
     * @return string
     */
    protected function getDefaultTemplate()
    {
        return 'checkout/failed.tpl';
    }

    /**
     * Return failed template
     *
     * @return string
     */
    abstract protected function getFailedTemplate();
}
